@@ -78,6 +78,11 @@ def agn_classifier(data, model_path=None):
 
     all_transformed, valid = fe.transform_data(formated, k.MINIMUM_POINTS)
 
+    # Filter empty alerts after filtering
+    all_empty = [i.empty for i in all_transformed]
+    if np.all(all_empty):
+        return np.zeros(len(data), dtype=np.float)
+
     all_features = fe.parametrise(all_transformed)
 
     features = fe.merge_features(all_features, k.MINIMUM_POINTS)
